#!/usr/bin/env python

# Template file for a post-processing code. For performance reasons,
# we store the whole trajectory in RAM and then analyze it.

# Beware: data analysis in python can be VERY slow! For better
# performance, you can try to use numpy arrays instead of lists.

import sys

def read(f):
    """Read the whole configuration from file f in xyz format.
    Return: a list of lists of box sides, positions and velocities."""
    pos_all = []
    vel_all = []
    box_all = []
    with open(f) as fh:
        data = fh.readlines()
        npart = int(data[0])
        # Assume number of particles is constant, it can be relaxed
        nconf = len(data) / (npart+2)
        for iconf in range(nconf):
            off = iconf*(npart+2)
            off_next = (iconf+1)*(npart+2)
            box = map(float, data[off+1].split())
            pos = []
            vel = []
            for line in data[off+2:off_next]:
                line_data = line.split()
                pos.append(map(float, line_data[1:4]))
                vel.append(map(float, line_data[4:7]))
            box_all.append(box)
            pos_all.append(pos)
            vel_all.append(vel)
    return box_all, pos_all, vel_all

def main(f):
    """Analyze trajectory"""
    L, pos, vel = read(f)
    print 'Read %d configurations' % len(pos)

if __name__ == '__main__':
    if len(sys.argv) == 1 or sys.argv[1] == '-h':
        print "Usage: %s <file>" % sys.argv[0]
        print "where <file> is the trajectory file to analyze"
        sys.exit()

    main(sys.argv[1])
